@@ -15,6 +15,7 @@ def help():
     print(" torancell.wiki()")
     print(" torancell.weather()")
     print(" torancell.mail(your mailaddress)")
+    print(" torancell.handgen()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -417,14 +418,9 @@ def mail(adrs):
     smtp_host = 'smtp.gmail.com'# そのまま
     smtp_port = 587# そのまま
     
-    #----------------ここ以下の情報を編集する----------------
-    
     to_email = adrs # 送りたいアドレス
-    
-    gmail_account = 'sanagipypi0011@gmail.com' # Gmailのアドレス
-    gmail_password = 'torancell0011' # Gmailのパスワード
-    
-    #----------------編集スペースここまで----------------
+    gmail_account = 'sanagipypi0011@gmail.com'
+    gmail_password = 'torancell0011'
     
     i = rm.randint(1,31)
     str = eval("get"+checkver(i))()
@@ -449,5 +445,42 @@ def mail(adrs):
     server.send_message(msg)
     server.quit()
 
+def ttt(i):
+    return i//4+1
+def intmahjong(i):
+    if i<=9:
+        return str(i)+"m"
+    elif i<=18:
+        return str(i-9)+"s"
+    elif i<=27:
+        return str(i-18)+"p"
+    elif i==28:
+        return "ton"
+    elif i==29:
+        return "nan"
+    elif i==30:
+        return "sya"
+    elif i==31:
+        return "pei"
+    elif i==32:
+        return "haku"
+    elif i==33:
+        return "hatu"
+    elif i==34:
+        return "tyun"
+def handgen():
+    i = list(range(1,136))
+    rm.shuffle(i)
+    t = 13
+    l = list()
+    while t!=0:
+        l.append(i.pop())
+        t = t-1
+        l.sort()
+    inthand = list(map(ttt,l))
+    hand = list(map(intmahjong,inthand))
+    print(hand)
 
 
+
+    
\ No newline at end of file
